@@ -3,7 +3,7 @@
 use strict;
 use Getopt::Long;
 use Pod::Usage;
-eval 'use Catalyst::Helper "1.0";';
+eval " use Catalyst::Devel 1.0; ";
 
 if ($@) {
   die <<END;
@@ -18,6 +18,8 @@ END
 
 }
 
+use Catalyst::Helper;
+
 my $force    = 0;
 my $help     = 0;
 my $makefile = 0;
