@@ -5,7 +5,7 @@
 # Note, to get this to run properly, you may need to give it the path to your
 # httpd.conf:
 #
-# perl t/optional_apache-cgi.pl -httpd_conf /etc/apache/httpd.conf
+# perl t/optional/apache-cgi.pl -httpd_conf /etc/apache/httpd.conf
 
 use strict;
 use warnings;
@@ -33,12 +33,6 @@ rmtree 't/tmp/TestApp/t';
 
 $ENV{CATALYST_SERVER} = 'http://localhost:8529/cgi';
 
-if ( !-e 't/optional_apache-cgi.pl' ) {
-    die "ERROR: Please run test from the Catalyst-Runtime directory\n";
-}
-
-push @ARGV, glob( 't/live_*' );
-
 Apache::TestRun->new->run(@ARGV);
 
 # clean up if the server has shut down
